polyfemos.front.sohplot.datacontainer — polyfemos 0.3.29 documentation

# polyfemos.front.sohplot.datacontainer

Classes for handling datapoints

copyright

  2019, University of Oulu, Sodankyla Geophysical Observatory

license

  GNU Lesser General Public License v3.0 or later (https://spdx.org/licenses/LGPL-3.0-or-later.html)

Public Functions

`polyfemos.front.sohplot.datacontainer.` `remove_timezone`(dt)
  Parameters

    dt (`datetime`) –

  Return type

    `datetime`

  Returns

    the function does nothing to the datetime object

`polyfemos.front.sohplot.datacontainer.` `remove_timezone_other`(dt)
  Parameters

    dt (`datetime`) –

  Return type

    `datetime`

  Returns

    a datetime instance without timezone

`polyfemos.front.sohplot.datacontainer.` `remove_timezone_py36`(dt)

  Used with python 3.6

  Parameters

    dt (`datetime`) –

  Return type

    `datetime`

  Returns

    a datetime instance without timezone

`polyfemos.front.sohplot.datacontainer.` `remove_timezone_py37`(dt)
  Parameters

    dt (`datetime`) –

  Return type

    `datetime`

  Returns

    the function does nothing to the datetime object

Private Functions

`polyfemos.front.sohplot.datacontainer.` `_track_datalen`(method)

  A decorator to be used with `DataContainer` to keep track of the datapoint amount and quantity of nan values. At the moment the looping of the datapoints is not very optimized.

  Parameters

    method (func) – A decorated method

  Return type

    func

  Returns

Classes

`DataContainer`([track_datalen, remove_identicals]) | A class to handle timeseries data consisting of `DataPoint` instances.
`DataPoint`([dtstr, timestamp, utcdatetime, y, z]) | A structlike class to store one datapoint in timeseries data